Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 215461)
+++ apps/app_voicemail.c	(working copy)
@@ -222,7 +222,19 @@
 					<option name="a">
 						<argument name="folder" required="true" />
 						<para>Skip folder prompt and go directly to <replaceable>folder</replaceable> specified.
-						Defaults to <literal>INBOX</literal>.</para>
+						Defaults to <literal>INBOX</literal> (or <literal>0</literal>).</para>
+						<enumlist>
+						<enum name="0"><para>INBOX</para></enum>
+						<enum name="1"><para>Old</para></enum>
+						<enum name="2"><para>Work</para></enum>
+						<enum name="3"><para>Family</para></enum>
+						<enum name="4"><para>Friends</para></enum>
+						<enum name="5"><para>Cust1</para></enum>
+						<enum name="6"><para>Cust2</para></enum>
+						<enum name="7"><para>Cust3</para></enum>
+						<enum name="8"><para>Cust4</para></enum>
+						<enum name="9"><para>Cust5</para></enum>
+						</enumlist>
 					</option>
 				</optionlist>
 			</parameter>
@@ -1429,29 +1441,43 @@
 	return 0;
 }
 
-static const char *mbox(int id)
-{
-	static const char * const msgs[] = {
+static const char * const mailbox_folders[] = {
 #ifdef IMAP_STORAGE
-		imapfolder,
+	imapfolder,
 #else
-		"INBOX",
+	"INBOX",
 #endif
-		"Old",
-		"Work",
-		"Family",
-		"Friends",
-		"Cust1",
-		"Cust2",
-		"Cust3",
-		"Cust4",
-		"Cust5",
-		"Deleted",
-		"Urgent"
-	};
-	return (id >= 0 && id < ARRAY_LEN(msgs)) ? msgs[id] : "Unknown";
+	"Old",
+	"Work",
+	"Family",
+	"Friends",
+	"Cust1",
+	"Cust2",
+	"Cust3",
+	"Cust4",
+	"Cust5",
+	"Deleted",
+	"Urgent"
+};
+
+static const char *mbox(int id)
+{
+	return (id >= 0 && id < ARRAY_LEN(mailbox_folders)) ? mailbox_folders[id] : "Unknown";
 }
 
+static int get_folder_by_name(const char *name)
+{
+	size_t i;
+
+	for (i = 0; i < ARRAY_LEN(mailbox_folders); i++) {
+		if (strcasecmp(name, mailbox_folders[i]) == 0) {
+			return i;
+		}
+	}
+
+	return -1;
+}
+
 static void free_user(struct ast_vm_user *vmu)
 {
 	if (ast_test_flag(vmu, VM_ALLOCED)) {
@@ -9044,16 +9070,24 @@
 			}
 			if (ast_test_flag(&flags, OPT_AUTOPLAY) ) {
 				play_auto = 1;
-				if (opts[OPT_ARG_PLAYFOLDER]) {
-					if (sscanf(opts[OPT_ARG_PLAYFOLDER], "%30d", &play_folder) != 1) {
-						ast_log(AST_LOG_WARNING, "Invalid value '%s' provided for folder autoplay option\n", opts[OPT_ARG_PLAYFOLDER]);
+				if (!ast_strlen_zero(opts[OPT_ARG_PLAYFOLDER])) {
+					/* See if it is a folder name first */
+					if (isdigit(opts[OPT_ARG_PLAYFOLDER][0])) {
+						if (sscanf(opts[OPT_ARG_PLAYFOLDER], "%30d", &play_folder) != 1) {
+							play_folder = -1;
+						}
+					} else {
+						play_folder = get_folder_by_name(opts[OPT_ARG_PLAYFOLDER]);
 					}
 				} else {
 					ast_log(AST_LOG_WARNING, "Invalid folder set with option a\n");
-				}	
-				if ( play_folder > 9 || play_folder < 0) {
-					ast_log(AST_LOG_WARNING, "Invalid value '%d' provided for folder autoplay option\n", play_folder);
+				}
+				if (play_folder > 9 || play_folder < 0) {
+					ast_log(AST_LOG_WARNING,
+						"Invalid value '%s' provided for folder autoplay option. Defaulting to 'INBOX'\n",
+						opts[OPT_ARG_PLAYFOLDER]);
 					play_folder = 0;
+					play_auto = 0;
 				}
 			}
 		} else {
